@@ -1,9 +1,13 @@
+
+#[cfg(not(feature = "std"))] use alloc::string::String;
+
 use crate::ColorTuple;
+use crate::common::f64_round;
 
 fn to_hex(n: f64) -> String {
-  let s = format!("{:x}", n.round() as u32);
+  let s = format!("{:x}", f64_round(n) as u32);
   if s.len() == 1 {
-    "0".to_string() + &s
+    String::from("0") + &s
   } else {
     s
   }
