@@ -1,6 +1,6 @@
-use crate::common::approx::approx_def;
 
 use super::consts::{ALL_MIN, HUE_MAX, PERCENT_MAX, RATIO_MAX, RGB_UNIT_MAX};
+use crate::common::{f64_round};
 
 fn normalize(val: f64, max: f64) -> f64 {
   if val < ALL_MIN {
@@ -16,15 +16,6 @@ pub fn normalize_percent(val: f64) -> f64 {
   normalize(val, PERCENT_MAX)
 }
 
-pub fn normalize_hue(h: f64) -> f64 {
-  let h = normalize(h, HUE_MAX);
-  if (h - HUE_MAX).abs() < std::f64::EPSILON {
-    0.0
-  } else {
-    h
-  }
-}
-
 pub fn normalize_rgb_unit(val: f64) -> f64 {
   normalize(val, RGB_UNIT_MAX)
 }
@@ -33,9 +24,6 @@ pub fn normalize_ratio(val: f64) -> f64 {
   normalize(val, RATIO_MAX)
 }
 
-pub fn normalize_opt_ratio(val: Option<f64>) -> Option<f64> {
-  val.map(normalize_ratio).filter(|al| !approx_def(*al, RATIO_MAX))
-}
 
 pub fn bound(r: f64, entire: f64) -> f64 {
   let mut n = r;
@@ -62,5 +50,5 @@ pub fn bound_hue(h: f64) -> f64 {
 }
 
 pub fn round_ratio(r: f64) -> f64 {
-  (r * 100.0).round() / 100.0
+  f64_round(r * 100.0) / 100.0
 }
