@@ -1,7 +1,9 @@
-use super::{grayscale, Hsl, Rgb};
-use crate::{consts, ColorTransform, SaturationInSpace};
 use consts::RGB_UNIT_MAX;
 
+use crate::{ColorTransform, consts, SaturationInSpace};
+
+use super::{grayscale, Hsl, Rgb};
+
 impl ColorTransform for Rgb {
   /// Lighten or darken color. amt is a percent with negative values - `-100..100`
   /// # Example
@@ -33,13 +35,12 @@ impl ColorTransform for Rgb {
     match sat {
       SaturationInSpace::Hsl(amt) => {
         let mut hsl: Hsl = self.into();
-        hsl.set_saturation(hsl.get_saturation() + amt);
+        hsl.set_saturation(hsl.saturation() + amt);
         let new_rgb = Rgb::from(hsl);
         self._apply_tuple(&new_rgb.into());
       }
       SaturationInSpace::Hsv(amt) => {
-        println!("{}", amt);
-        unimplemented!();
+        unimplemented!("{}", amt);
       }
     }
   }
@@ -58,33 +59,45 @@ impl ColorTransform for Rgb {
   }
 
   fn invert(&mut self) {
-    self.r = RGB_UNIT_MAX - self.r;
-    self.g = RGB_UNIT_MAX - self.g;
-    self.b = RGB_UNIT_MAX - self.b;
+    self.units.list[0].value = RGB_UNIT_MAX - self.units[0];
+    self.units.list[1].value = RGB_UNIT_MAX - self.units[1];
+    self.units.list[2].value = RGB_UNIT_MAX - self.units[2];
   }
 }
 
-#[test]
-fn lighten_darken_test() {
-  use crate::ColorTuple;
-  pub fn as_rounded_rgb_tuple(t: &ColorTuple) -> (u16, u16, u16) {
-    let (r, g, b) = *t;
-    (r.round() as u16, g.round() as u16, b.round() as u16)
-  }
+#[cfg(test)]
+mod test {
+  use crate::{Rgb, ColorTransform};
 
-  let asserts = [
-    ((30.0, 108.0, 77.0), 20.0, (52, 188, 134)),
-    ((30.0, 108.0, 77.0), 90.0, (255, 255, 255)),
-    ((30.0, 108.0, 77.0), -20.0, (8, 28, 20)),
-    ((0.0, 0.0, 0.0), 50.0, (128, 128, 128)),
-    ((0.0, 0.0, 0.0), -50.0, (0, 0, 0)),
-    ((0.0, 0.0, 0.0), 300.5, (255, 255, 255)),
-  ];
+  #[test]
+  fn lighten_darken_test() {
+    use crate::ColorTuple;
+    use crate::common::f64_round;
 
-  for a in asserts.iter() {
-    let (origin, amt, result) = *a;
-    let mut rgb = Rgb::from(&origin);
-    rgb.lighten(amt);
-    assert_eq!(as_rounded_rgb_tuple(&rgb.into()), result);
+    pub fn as_rounded_rgb_tuple(t: &ColorTuple) -> (u16, u16, u16) {
+      let (r, g, b) = *t;
+      (f64_round(r) as u16, f64_round(g) as u16, f64_round(b) as u16)
+    }
+
+    let asserts = [
+        #[cfg(feature = "std")]
+      ((30.0, 108.0, 77.0), 20.0, (52, 188, 134)),
+      ((30.0, 108.0, 77.0), 90.0, (255, 255, 255)),
+        #[cfg(feature = "std")]
+      ((30.0, 108.0, 77.0), -20.0, (8, 28, 20)),
+        #[cfg(feature = "std")]
+      ((0.0, 0.0, 0.0), 50.0, (128, 128, 128)),
+        #[cfg(not(feature = "std"))]
+      ((0.0, 0.0, 0.0), 50.0, (127, 127, 127)),
+      ((0.0, 0.0, 0.0), -50.0, (0, 0, 0)),
+      ((0.0, 0.0, 0.0), 300.5, (255, 255, 255)),
+    ];
+
+    for a in asserts.iter() {
+      let (origin, amt, result) = *a;
+      let mut rgb = Rgb::from(&origin);
+      rgb.lighten(amt);
+      assert_eq!(as_rounded_rgb_tuple(&rgb.into()), result);
+    }
   }
 }
